From ed9d88fc9a628a99ae1c134dbc18c14bb4f686fd Mon Sep 17 00:00:00 2001
From: Le Wang <le.wang@agworld.com.au>
Date: Sat, 12 Jan 2013 22:58:14 +0800
Subject: [PATCH 1/2] add tests for round-trip source block without change

- When the source block isn't changed in the source buffer, modified
  status should not change.
---
 testing/lisp/test-org-src.el | 29 +++++++++++++++++++++++++++++
 1 file changed, 29 insertions(+)

diff --git a/testing/lisp/test-org-src.el b/testing/lisp/test-org-src.el
index 958a7bc..ca0442f 100644
--- a/testing/lisp/test-org-src.el
+++ b/testing/lisp/test-org-src.el
@@ -96,5 +96,34 @@
 #+end_src
 "))))
 
+(ert-deftest test-org-src/no-change ()
+  "Not changing contents should not change buffer-modified status."
+  (org-test-with-temp-text
+   "
+#+begin_src emacs-lisp
+  (message hello)
+#+end_src
+"
+   (goto-line 2)
+   (set-buffer-modified-p nil)
+   (org-edit-special)
+   (org-edit-src-exit)
+   (should (equal (buffer-modified-p) nil))))
+
+(ert-deftest test-org-src/no-change-empty-block ()
+  "Not changing contents should change buffer-modified status
+when newline has to be added."
+
+  (org-test-with-temp-text
+   "
+#+begin_src emacs-lisp
+#+end_src
+"
+   (goto-line 2)
+   (set-buffer-modified-p nil)
+   (org-edit-special)
+   (org-edit-src-exit)
+   (should (equal (buffer-modified-p) t))))
+
 (provide 'test-org-src)
 ;;; test-org-src.el ends here
-- 
1.7.11.4

